@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.59 2002/09/19 17:22:44 gman Exp $ */
+/* $Id: gdict-app.c,v 1.60 2003/05/19 11:08:13 gman Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -101,6 +101,10 @@ gdict_init_context (void)
     
     defbox->context = context;
 
+#ifdef ENABLE_IPV6
+    if (context->host6info)
+	return 0;
+#endif
     if (context->hostinfo)
 	return 0;
     else
