@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.33 2002/07/30 13:18:01 gman Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.34 2003/05/18 17:15:52 dcransto Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -185,14 +185,15 @@ create_dialog (GDictPrefDialog *pref_dialog)
     
     gtk_window_set_title (GTK_WINDOW (pref_dialog), _("Dictionary Preferences"));
     gtk_window_set_policy (GTK_WINDOW (pref_dialog), FALSE, FALSE, FALSE);    
+    gtk_container_set_border_width (GTK_CONTAINER (pref_dialog), 5);
     vbox = GTK_DIALOG (pref_dialog)->vbox;
 
     
     pref_dialog->table = GTK_TABLE (gtk_table_new (5, 3, FALSE));
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox), GTK_WIDGET (pref_dialog->table), TRUE, TRUE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (pref_dialog->table), 8);
+    gtk_container_set_border_width (GTK_CONTAINER (pref_dialog->table), 5);
     gtk_table_set_row_spacings (pref_dialog->table, 6);
-    gtk_table_set_col_spacings (pref_dialog->table, 6);
+    gtk_table_set_col_spacings (pref_dialog->table, 12);
 
     pref_dialog->smart_lookup_btn = 
         GTK_CHECK_BUTTON (gtk_check_button_new_with_mnemonic (_("Smart _lookup")));
@@ -201,22 +202,28 @@ create_dialog (GDictPrefDialog *pref_dialog)
     gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (pref_dialog->smart_lookup_btn),
     			       1, 3, 2, 3);
     
-    pref_dialog->server_entry = GTK_ENTRY (gtk_entry_new ());
-    gtk_table_attach_defaults (pref_dialog->table, 
-                               GTK_WIDGET (pref_dialog->server_entry), 
-                               1, 2, 0, 1);
+    pref_dialog->server_entry = GTK_ENTRY (gtk_entry_new ());			       
+    gtk_table_attach (pref_dialog->table, 
+                      GTK_WIDGET (pref_dialog->server_entry),
+                      1, 2, 0, 1,
+                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+		    
     g_signal_connect (G_OBJECT (pref_dialog->server_entry), "focus_out_event",
     		      G_CALLBACK (set_server_cb), pref_dialog);
     
     server_label = gtk_label_new_with_mnemonic (_("_Server:"));
     gtk_label_set_mnemonic_widget (GTK_LABEL (server_label), 
     				   GTK_WIDGET (pref_dialog->server_entry));
-    gtk_label_set_justify (GTK_LABEL (server_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (server_label), 1, 0.5);
+    gtk_label_set_justify (GTK_LABEL (server_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (server_label), 0, 0.5);
     gtk_table_attach_defaults (pref_dialog->table, server_label, 0, 1, 0, 1);
     
     button = gtk_button_new_with_mnemonic (_("De_fault Server"));
-    gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 0, 1);
+    gtk_table_attach (pref_dialog->table, 
+                      button, 2, 3, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
     g_signal_connect (G_OBJECT (button), "clicked",
     		      G_CALLBACK (set_default_server), pref_dialog);
 
@@ -225,20 +232,25 @@ create_dialog (GDictPrefDialog *pref_dialog)
 
     port_label = gtk_label_new_with_mnemonic (_("_Port:"));
     gtk_table_attach_defaults (pref_dialog->table, port_label, 0, 1, 1, 2);
-    gtk_label_set_justify (GTK_LABEL (port_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (port_label), 1, 0.5);
+    gtk_label_set_justify (GTK_LABEL (port_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (port_label), 0, 0.5);
 
     pref_dialog->port_entry = GTK_ENTRY (gtk_entry_new ());
     gtk_label_set_mnemonic_widget (GTK_LABEL (port_label), 
     				   GTK_WIDGET (pref_dialog->port_entry));
-    gtk_table_attach_defaults (pref_dialog->table, 
-                               GTK_WIDGET (pref_dialog->port_entry), 
-                               1, 2, 1, 2);
+    gtk_table_attach (pref_dialog->table, 
+                      GTK_WIDGET (pref_dialog->port_entry),
+                      1, 2, 1, 2,
+                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
     g_signal_connect (G_OBJECT (pref_dialog->port_entry), "focus_out_event",
     		      G_CALLBACK (set_port_cb), pref_dialog);
                                
     button = gtk_button_new_with_mnemonic (_("Def_ault Port"));
-    gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 1, 2);
+    gtk_table_attach (pref_dialog->table, 
+                      button, 2, 3, 1, 2,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
     g_signal_connect (G_OBJECT (button), "clicked",
     		      G_CALLBACK (set_default_port), pref_dialog);
     
@@ -256,15 +268,15 @@ create_dialog (GDictPrefDialog *pref_dialog)
     }
 
     db_label = gtk_label_new_with_mnemonic (_("_Database:"));
-    gtk_label_set_justify (GTK_LABEL (db_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (db_label), 1, 0.5);
+    gtk_label_set_justify (GTK_LABEL (db_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (db_label), 0, 0.5);
     gtk_table_attach_defaults (pref_dialog->table, db_label, 0, 1, 3, 4);
     pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
     gtk_widget_show (GTK_WIDGET (pref_dialog->db_list));
     
     strat_label = gtk_label_new_with_mnemonic (_("D_efault strategy:"));
-    gtk_label_set_justify (GTK_LABEL (strat_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (strat_label), 1, 0.5);
+    gtk_label_set_justify (GTK_LABEL (strat_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (strat_label), 0, 0.5);
     gtk_table_attach_defaults (pref_dialog->table, strat_label, 0, 1, 4, 5);
     pref_dialog->strat_list = GTK_MENU (gtk_menu_new ());
     gtk_widget_show (GTK_WIDGET (pref_dialog->strat_list));
@@ -275,6 +287,7 @@ create_dialog (GDictPrefDialog *pref_dialog)
     			    GTK_RESPONSE_CLOSE, GTK_STOCK_HELP, GTK_RESPONSE_HELP, NULL);  
 
     gtk_dialog_set_default_response (GTK_DIALOG (pref_dialog), GTK_RESPONSE_CLOSE);
+    gtk_dialog_set_has_separator (GTK_DIALOG (pref_dialog), FALSE);
     
     g_signal_connect (G_OBJECT (pref_dialog), "response",
     		      G_CALLBACK (response_cb), NULL);
