@@ -85,6 +85,9 @@ limit_string_to_x_lines		(GString *string,
 gchar *	
 escape_single_quotes 		(const gchar *string);
 
+gchar *
+remove_mnemonic_character	(const gchar *string);
+
 gint 	 	
 count_of_char_in_string		(const gchar *string, 
 				 const gchar q);
@@ -118,6 +121,13 @@ open_file_with_application 	(const gchar *filename);
 gboolean
 launch_file 			(const gchar *filename);
 
+gboolean 
+gsearchtool_gconf_get_boolean 	(const gchar *key);
+
+void
+gsearchtool_gconf_set_boolean 	(const gchar *key, 
+				 const gboolean flag);
+
 #ifdef __cplusplus
 }
 #endif
