@@ -391,7 +391,7 @@ CreateMainWin ()
 
    /* Create App */
 
-   if ((curlog != NULL) && (numlogs))
+   if ((curlog != NULL) && (curlog->name != NULL) && (numlogs))
        window_title = g_strdup_printf ("%s - %s", curlog->name, APP_NAME);
    else
        window_title = g_strdup_printf (APP_NAME);
@@ -866,7 +866,7 @@ void SetDefaultUserPrefs(UserPrefsStruct *prefs)
 	gchar *logfile = NULL;
 	struct stat filestat;
 	
-	logfile = gconf_client_get_string (client, "/apps/logview/logfile", NULL);
+	logfile = gconf_client_get_string (client, "/apps/gnome-system-log/logfile", NULL);
 	if (logfile != NULL && strcmp (logfile, "")) {
 		prefs->logfile = g_strdup (logfile);
 		g_free (logfile);
@@ -882,7 +882,6 @@ void SetDefaultUserPrefs(UserPrefsStruct *prefs)
 		else
 			prefs->logfile = NULL;
 	}
-	g_free (logfile);
 }
 
 void SaveUserPrefs(UserPrefsStruct *prefs)
